@@ -6,7 +6,7 @@ package Config::Grammar;
 use strict;
 
 use vars qw($VERSION);
-$VERSION = '1.00';
+$VERSION = '1.01';
 
 sub new($$)
 {
@@ -1470,33 +1470,22 @@ The data is interpreted as one or more columns separated by spaces.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2000, 2001 by ETH Zurich. All rights reserved.
+Copyright (c) 2000-2005 by ETH Zurich. All rights reserved.
 
 =head1 LICENSE
 
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
-(at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+This program is free software; you can redistribute it and/or modify it
+under the same terms as Perl itself.
 
 =head1 AUTHOR
 
-David Schweikert E<lt>dws@ee.ethz.chE<gt>,
-Tobias Oetiker E<lt>oetiker@ee.ethz.chE<gt>,
-Niko Tyni  E<lt>ntyni@iki.fiE<gt>
+David Schweikert E<lt>dws_at_ee.ethz.chE<gt>,
+Tobias Oetiker E<lt>oetiker_at_ee.ethz.chE<gt>,
+Niko Tyni  E<lt>ntyni_at_iki.fiE<gt>
 
 =head1 HISTORY
 
- 2001-05-11 ds      Initial Version of Config::Grammar
+ 2001-05-11 ds      Initial Version of ISG::ParseConfig
  2005-03-08 ds 1.00 Renamed from ISG::ParseConfig to Config::Grammar 
 
 =cut
